This is a hypothetical dataset created as an example to faciliate user's learning of the function used in the package while processing the black carbon data with ONA algorithm
Usage
data("data_ONA")
Arguments
Format
A data frame with 31118 observations on the following 2 variables.